@@ -412,6 +412,7 @@ class Database(object):
                 self.initialize(self.path)
         if not 'id' in self.indexes_names and with_id_index:
             import CodernityDB.hash_index
+            print 'abc'
             if not 'db_path' in index_kwargs:
                 index_kwargs['db_path'] = self.path
             index_kwargs['name'] = 'id'
@@ -419,7 +420,10 @@ class Database(object):
             self.add_index(id_ind, create=False)
             # del CodernityDB.index
         for index in self.indexes:
-            index.create_index()
+            try:
+                index.create_index()
+            except IndexException:
+                raise DatabaseConflict("Already exists (detected on index=%s)" % index.name)
         return True
 
     def _read_indexes(self):
